"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toTSX = exports.extension = exports.languageId = void 0;
const compiler_sfc_1 = require("@vue/compiler-sfc");
exports.languageId = 'vue';
exports.extension = '.vue';
function toTSX(code, className) {
    let result = `export default function ${className}__AstroComponent_(): any {}`;
    // NOTE: As you can expect, using regexes for this is not exactly the most reliable way of doing things
    // However, I couldn't figure out a way to do it using Vue's compiler, I tried looking at how Volar does it, but I
    // didn't really understand everything happening there and it seemed to be pretty Volar-specific. I do believe
    // someone more knowledgable on Vue's internals could figure it out, but since this solution is good enough for most
    // Vue components (and it's an improvement over, well, nothing), it's alright, I think
    try {
        const parsedResult = (0, compiler_sfc_1.parse)(code);
        if (parsedResult.descriptor.scriptSetup) {
            const definePropsType = parsedResult.descriptor.scriptSetup.content.match(/defineProps<([\s\S]+)>/m);
            if (definePropsType) {
                result = `
						${parsedResult.descriptor.scriptSetup.content}

						export default function ${className}__AstroComponent_(_props: ${definePropsType[1]}): any {
							<div></div>
						}
				`;
            }
            else {
                const defineProps = parsedResult.descriptor.scriptSetup.content.match(/defineProps\([\s\S]+\)/m);
                if (defineProps) {
                    result = `
					import { defineProps } from '@vue/runtime-core';

					const Props = ${defineProps[0]}

					export default function ${className}__AstroComponent_(_props: typeof Props): any {
						<div></div>
					}
				`;
                }
            }
        }
    }
    catch (e) {
        return result;
    }
    return result;
}
exports.toTSX = toTSX;
